v3.0.0
======

Refresh packaging. Require Python 3.6 or later.

2.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.1
===

* Added jaraco.office.excel.get_workbook_as_xml (from jaraco.util.excel module).

1.0
===

* Initial release.
* Includes jaraco.office.convert for converting Word documents to PDF (even
  includes a server for hosting the conversion process over HTTP).
